#line 1 "src/scan-gram.c"

#line 3 "src/scan-gram.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

/* %not-for-header */
/* %if-c-only */
/* %if-not-reentrant */
#define yy_create_buffer gram__create_buffer
#define yy_delete_buffer gram__delete_buffer
#define yy_scan_buffer gram__scan_buffer
#define yy_scan_string gram__scan_string
#define yy_scan_bytes gram__scan_bytes
#define yy_init_buffer gram__init_buffer
#define yy_flush_buffer gram__flush_buffer
#define yy_load_buffer_state gram__load_buffer_state
#define yy_switch_to_buffer gram__switch_to_buffer
#define yypush_buffer_state gram_push_buffer_state
#define yypop_buffer_state gram_pop_buffer_state
#define yyensure_buffer_stack gram_ensure_buffer_stack
#define yy_flex_debug gram__flex_debug
#define yyin gram_in
#define yyleng gram_leng
#define yylex gram_lex
#define yylineno gram_lineno
#define yyout gram_out
#define yyrestart gram_restart
#define yytext gram_text
#define yywrap gram_wrap
#define yyalloc gram_alloc
#define yyrealloc gram_realloc
#define yyfree gram_free

/* %endif */
/* %endif */
/* %ok-for-header */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* %if-c++-only */
/* %endif */

/* %if-c-only */
#ifdef yy_create_buffer
#define gram__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer gram__create_buffer
#endif

#ifdef yy_delete_buffer
#define gram__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer gram__delete_buffer
#endif

#ifdef yy_scan_buffer
#define gram__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer gram__scan_buffer
#endif

#ifdef yy_scan_string
#define gram__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string gram__scan_string
#endif

#ifdef yy_scan_bytes
#define gram__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes gram__scan_bytes
#endif

#ifdef yy_init_buffer
#define gram__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer gram__init_buffer
#endif

#ifdef yy_flush_buffer
#define gram__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer gram__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define gram__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state gram__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define gram__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer gram__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define gram_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state gram_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define gram_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state gram_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define gram_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack gram_ensure_buffer_stack
#endif

#ifdef yylex
#define gram_lex_ALREADY_DEFINED
#else
#define yylex gram_lex
#endif

#ifdef yyrestart
#define gram_restart_ALREADY_DEFINED
#else
#define yyrestart gram_restart
#endif

#ifdef yylex_init
#define gram_lex_init_ALREADY_DEFINED
#else
#define yylex_init gram_lex_init
#endif

#ifdef yylex_init_extra
#define gram_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra gram_lex_init_extra
#endif

#ifdef yylex_destroy
#define gram_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy gram_lex_destroy
#endif

#ifdef yyget_debug
#define gram_get_debug_ALREADY_DEFINED
#else
#define yyget_debug gram_get_debug
#endif

#ifdef yyset_debug
#define gram_set_debug_ALREADY_DEFINED
#else
#define yyset_debug gram_set_debug
#endif

#ifdef yyget_extra
#define gram_get_extra_ALREADY_DEFINED
#else
#define yyget_extra gram_get_extra
#endif

#ifdef yyset_extra
#define gram_set_extra_ALREADY_DEFINED
#else
#define yyset_extra gram_set_extra
#endif

#ifdef yyget_in
#define gram_get_in_ALREADY_DEFINED
#else
#define yyget_in gram_get_in
#endif

#ifdef yyset_in
#define gram_set_in_ALREADY_DEFINED
#else
#define yyset_in gram_set_in
#endif

#ifdef yyget_out
#define gram_get_out_ALREADY_DEFINED
#else
#define yyget_out gram_get_out
#endif

#ifdef yyset_out
#define gram_set_out_ALREADY_DEFINED
#else
#define yyset_out gram_set_out
#endif

#ifdef yyget_leng
#define gram_get_leng_ALREADY_DEFINED
#else
#define yyget_leng gram_get_leng
#endif

#ifdef yyget_text
#define gram_get_text_ALREADY_DEFINED
#else
#define yyget_text gram_get_text
#endif

#ifdef yyget_lineno
#define gram_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno gram_get_lineno
#endif

#ifdef yyset_lineno
#define gram_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno gram_set_lineno
#endif

#ifdef yywrap
#define gram_wrap_ALREADY_DEFINED
#else
#define yywrap gram_wrap
#endif

/* %endif */

#ifdef yyalloc
#define gram_alloc_ALREADY_DEFINED
#else
#define yyalloc gram_alloc
#endif

#ifdef yyrealloc
#define gram_realloc_ALREADY_DEFINED
#else
#define yyrealloc gram_realloc
#endif

#ifdef yyfree
#define gram_free_ALREADY_DEFINED
#else
#define yyfree gram_free
#endif

/* %if-c-only */

#ifdef yytext
#define gram_text_ALREADY_DEFINED
#else
#define yytext gram_text
#endif

#ifdef yyleng
#define gram_leng_ALREADY_DEFINED
#else
#define yyleng gram_leng
#endif

#ifdef yyin
#define gram_in_ALREADY_DEFINED
#else
#define yyin gram_in
#endif

#ifdef yyout
#define gram_out_ALREADY_DEFINED
#else
#define yyout gram_out
#endif

#ifdef yy_flex_debug
#define gram__flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug gram__flex_debug
#endif

#ifdef yylineno
#define gram_lineno_ALREADY_DEFINED
#else
#define yylineno gram_lineno
#endif

/* %endif */

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
/* %if-c-only */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>
/* %endif */

/* %if-tables-serialization */
/* %endif */
/* end standard C headers. */

/* %if-c-or-c++ */
/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* %endif */

/* begin standard C++ headers. */
/* %if-c++-only */
/* %endif */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* %not-for-header */
/* Returned upon end-of-file. */
#define YY_NULL 0
/* %ok-for-header */

/* %not-for-header */
/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))
/* %ok-for-header */

/* %if-reentrant */
/* %endif */

/* %if-not-reentrant */

/* %endif */

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

/* %if-not-reentrant */
extern int yyleng;
/* %endif */

/* %if-c-only */
/* %if-not-reentrant */
extern FILE *yyin, *yyout;
/* %endif */
/* %endif */

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
/* %if-c-only */
	FILE *yy_input_file;
/* %endif */

/* %if-c++-only */
/* %endif */

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */
/* %if-not-reentrant */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */
/* %endif */
/* %ok-for-header */

/* %endif */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* %if-c-only Standard (non-C++) definition */

/* %if-not-reentrant */
/* %not-for-header */
/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;
/* %ok-for-header */

/* %endif */

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

/* %endif */

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* %% [1.0] yytext/yyin/yyout/yy_state_type/yylineno etc. def's & init go here */
/* Begin user sect3 */

#define gram_wrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

#define FLEX_DEBUG
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

/* %% [1.5] DFA */

/* %if-c-only Standard (non-C++) definition */

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* %endif */

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
/* %% [2.0] code to fiddle yytext and yyleng for yymore() goes here \ */\
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
/* %% [3.0] code to copy yytext_ptr to yytext[] goes here, if %array \ */\
	(yy_c_buf_p) = yy_cp;
/* %% [4.0] data tables for the DFA and the user's section 1 definitions go here */
#define YY_NUM_RULES 127
#define YY_END_OF_BUFFER 128
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[600] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   91,   91,  111,  111,  111,  111,    0,    0,
        0,    0,  128,   78,    2,    2,    2,   69,   78,   68,
       78,    1,   64,   78,   65,   65,   60,   63,   75,   61,
       64,   77,   71,   62,   78,   88,   88,   88,  126,  126,
       93,  126,   92,  126,  126,  126,  126,  126,  126,  126,
      126,   79,   95,  126,   94,   82,    2,    2,    1,   82,
       81,   80,   82,   97,   97,   98,   96,   79,  117,  126,
      116,  126,  126,  126,  120,  123,  124,  126,   90,  126,

      126,  115,  126,  114,  126,  113,  126,  112,   85,    2,
        2,    1,   83,   85,   85,   84,   85,   86,    2,    2,
        1,   86,   86,   78,    2,   76,   59,    0,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   70,   64,   64,    4,
        3,   67,   65,   67,    0,   74,    0,   88,   87,   93,
      110,  110,  108,   99,  110,  101,  102,  103,  104,  105,
      106,  110,  107,  110,  126,    0,    0,    0,    0,    0,
        0,   95,   97,   97,   98,  125,  118,  119,    0,  121,
        0,  120,  122,    0,   89,    0,   90,    0,   91,    0,

      115,  111,  111,  111,  111,  111,  113,   85,   83,   59,
        0,    0,   72,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,    3,   67,   66,   73,    0,   99,
        0,    0,  100,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,

       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,    0,   99,    0,    0,   59,    7,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   21,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   33,   59,   59,
       59,   59,   59,   59,   40,   59,   43,   59,   59,   46,
        0,    0,    0,   59,    8,   59,   59,   59,   13,   14,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   24,
       59,   59,   59,   59,   59,   59,   59,   29,   59,   31,
       59,   59,   59,   59,   59,   37,   59,   39,   41,   44,

       59,    0,    0,  109,    6,   59,   10,   59,   59,   59,
       15,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   30,   59,   59,   59,   59,
       59,   59,   59,   59,   59,    0,   59,   11,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,    0,   57,   59,
       59,   35,   59,   36,   59,   59,   59,   45,    5,    0,
        0,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   20,   59,   59,   59,   59,   26,   59,   56,
       27,   59,   59,   59,   59,   38,   59,   59,    0,   59,

       59,   59,   59,   59,   16,   52,   59,   59,   59,   59,
       22,   23,   59,   59,   59,   59,   59,   59,   59,   59,
       59,    0,    0,   59,   59,   12,   59,   59,   59,   59,
       19,   59,   59,   59,   59,   59,   59,   34,   59,   59,
       59,    0,   59,   59,   59,   59,   17,   59,   59,   49,
       59,   59,   59,   32,   47,   42,   58,    9,   50,   59,
       59,    0,   53,   59,   59,   49,   49,   59,   59,   59,
       48,   51,   59,   59,   49,   59,   59,   59,   59,   18,
       59,   59,   59,   59,   25,   55,   59,   59,   59,   59,
       59,   54,   59,   59,   59,   59,   59,   28,    0

    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    5,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    6,    7,    8,    9,    7,   10,    7,   11,    7,
        7,   12,    7,   13,   14,   15,   16,   17,   18,   18,
       18,   18,   18,   18,   18,   19,   19,   20,   21,   22,
       23,   24,   25,   26,   27,   27,   27,   27,   27,   27,
       28,   28,   28,   28,   28,   28,   28,   28,   28,   28,
       28,   28,   28,   28,   29,   28,   28,   30,   28,   28,
       31,   32,   33,   26,   34,   26,   35,   36,   37,   38,

       39,   40,   41,   42,   43,   28,   44,   45,   46,   47,
       48,   49,   50,   51,   52,   53,   54,   55,   28,   56,
       57,   28,   58,   59,   60,   26,   61,   62,   62,   62,
       62,   62,   62,   62,   62,   62,   62,   62,   62,   62,
       62,   62,   62,   63,   63,   63,   63,   63,   63,   63,
       63,   63,   63,   63,   63,   63,   63,   63,   63,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,    1,    1,   65,   65,   65,   65,   65,   65,   65,

       65,   65,   65,   65,   65,   65,   65,   65,   65,   65,
       65,   65,   65,   65,   65,   65,   65,   65,   65,   65,
       65,   65,   65,   66,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   68,   67,   67,   69,
       70,   70,   70,   71,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[73] =
    {   0,
        1,    2,    3,    2,    2,    2,    1,    4,    1,    4,
        4,    4,    4,    5,    6,    2,    7,    7,    7,    8,
        9,   10,    9,   10,    8,    8,    7,    7,    7,    7,
       11,    8,   12,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    9,    9,    9,
        8,    8,    8,    8,    1,    1,    1,    1,    1,    1,
        1,    8
    } ;

static const flex_int16_t yy_base[618] =
    {   0,
        0, 1341,   68,   69,   81,  153,   85,   89,   99,  105,
      102,  109,  157,  161,  231,  301,  179,  194,  371,  441,
      195,  247,  241,  253,  266,  267,  273,  319,  513, 1340,
      344,  362, 1348,    0, 1351, 1351, 1344, 1351,  576, 1351,
     1351, 1351,  634,   63,  278,   59,    0, 1351,   71, 1351,
        0, 1351, 1351, 1351, 1301, 1351, 1342, 1328, 1351, 1351,
     1351, 1340, 1351,  702,   65, 1278,   75,   36,    0,  116,
     1279, 1351, 1351, 1337, 1351, 1351, 1351, 1336, 1351,   75,
     1351, 1351, 1293, 1323,  108, 1314, 1351, 1321, 1351, 1274,
     1351,  143,  159,  255, 1351, 1351, 1351,  154, 1351, 1330,

      338, 1351, 1329, 1351,  392, 1351, 1328, 1351,    0, 1351,
     1327,    0,    0,  176, 1351, 1351, 1284, 1351, 1351, 1325,
     1351,  192, 1282,    0, 1351, 1351,    0,  350, 1283, 1277,
      157,  184, 1281, 1278, 1275,  253, 1282,  267, 1266,  177,
      170,  201,  344, 1272, 1279, 1282, 1351,    0,    0, 1351,
        0,    0,  318,  398, 1292, 1351, 1272, 1351, 1351, 1351,
     1351, 1311, 1351,  117,  441, 1351, 1351, 1351, 1351, 1351,
     1351,  447, 1351,  471, 1351,  322,  326,  342,  347,  350,
      356, 1351, 1299,  224, 1290, 1351, 1351, 1351,  489, 1351,
      590, 1351, 1351,  634, 1351,  712, 1351,  719, 1279, 1307,

     1351, 1351,  741, 1277, 1305,  757, 1351,    0,    0,    0,
      762, 1304, 1351, 1259, 1267,  228, 1253, 1254, 1251, 1252,
       61, 1249, 1256, 1251,  254, 1260, 1245, 1249,  393, 1255,
     1240, 1241,  243, 1240, 1240, 1248, 1249, 1252, 1235, 1241,
     1235, 1240, 1231, 1244,    0,    0,    0, 1351, 1233,  123,
      752,  758,  786,  359,  391,  407,  778,  416, 1276,  804,
      294, 1275,  812,  348, 1274,  825,  284, 1273,  830,  835,
     1272,  840,  845,  464, 1271, 1238, 1233, 1217,  286, 1217,
     1230, 1215, 1219, 1227, 1226, 1225, 1249, 1209, 1220, 1207,
     1245, 1223, 1216, 1217,  156,  245,  222, 1204, 1205,  279,

     1216, 1205, 1212, 1196, 1207, 1203, 1196, 1200, 1206, 1205,
     1195, 1206, 1204, 1201, 1351,  835,  841, 1188,    0, 1197,
     1183, 1189, 1184, 1197, 1176, 1181, 1194, 1216, 1191, 1179,
     1184, 1172,    0, 1176, 1171, 1184,  416, 1183, 1178, 1181,
     1176, 1166, 1178, 1170, 1161, 1168, 1174, 1173, 1158,  427,
     1167, 1156, 1169, 1154,    0, 1159,    0, 1158, 1156,    0,
     1197,  865,  871, 1145,    0, 1156, 1161, 1145,    0,    0,
      428, 1145, 1148,  573, 1161, 1160, 1159, 1158, 1149,    0,
     1142, 1150, 1142, 1148, 1140, 1134, 1132,    0, 1131,    0,
     1169, 1144, 1142, 1131, 1128,    0, 1125,    0,  574,    0,

     1125,  485,  895, 1351,    0, 1123, 1123, 1137, 1118, 1117,
      575, 1120, 1122, 1118, 1123, 1126, 1115, 1117, 1113, 1128,
     1123, 1126, 1121, 1111, 1119,  913, 1108, 1117, 1104, 1119,
     1114, 1104, 1098, 1097, 1110,  639,  678,    0, 1095, 1108,
     1107, 1094, 1093, 1104, 1088, 1080, 1103, 1065, 1068, 1053,
     1060, 1031,  999,  996,  997, 1010,  993,  921, 1351, 1008,
      995,    0,  928,    0,  931,  942,  941,    0, 1351,  972,
      966,  924,  923,  922,  918,  917,  916,  914,  924,  904,
      917,  920,    0,  897,  890,  889,  883,    0,  876,    0,
        0,  874,  848,  854,  835,    0,  850,  849,  861,  810,

      806,  805,  819,  783,    0,    0,  769,  762,  751,  764,
        0,    0,  757,  746,  733,  735,  739,  734,  733,  709,
      707,  743,  594,  709,  702,    0,  692,  691,  680,  681,
        0,  680,  676,  694,  695,  679,  665,    0,  643,  654,
      626,  229,  618,  613,  595,  594,  935,  547,  555,  943,
      541,  463,  462,    0,    0,    0,    0,    0,    0,  461,
      458,  948, 1351,  716,  427,  957,  861,  421,  405,  395,
        0,    0,  405,  392,  891,  387,  363,  347,  356,    0,
      340,  335,  326,  318,    0,    0,  325,  293,  314,  255,
      244,    0,  227,  192,  124,  124,   69,    0, 1351,  980,

      992, 1004, 1016, 1028, 1040, 1047, 1050, 1057, 1063, 1075,
     1087, 1097, 1104, 1107, 1114, 1122, 1129
    } ;

static const flex_int16_t yy_def[618] =
    {   0,
      599,    1,  600,  600,  601,  601,    6,    6,  602,  602,
      603,  603,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,  599,   29,
      604,  604,  599,  605,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  606,  606,  605,  599,  599,  599,
      607,  599,  599,  599,  605,  599,  599,  599,  599,  599,
      599,  599,  599,  608,  599,  599,  599,  599,  609,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  610,  610,  599,  599,  610,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,

      599,  599,  599,  599,  611,  599,  599,  599,  612,  599,
      599,  612,  613,  599,  599,  599,  612,  599,  599,  599,
      599,  599,  599,  605,  599,  599,  614,  599,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  599,   43,  607,  599,
      615,  616,  606,  616,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  610,  610,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,

      599,  599,  599,  599,  599,  599,  599,  612,  613,  614,
      599,  599,  599,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  615,  616,  154,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  611,  599,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,

      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  599,  599,  599,  599,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      599,  599,  599,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,

      614,  599,  599,  599,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  599,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  599,  599,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  599,  599,
      599,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  617,  614,

      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  617,  617,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  617,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  599,  599,  614,  614,  599,  599,  614,  614,  614,
      614,  614,  614,  614,  599,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,    0,  599,

      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599
    } ;

static const flex_int16_t yy_nxt[1424] =
    {   0,
       34,   35,   36,   35,   37,   35,   34,   38,   34,   39,
       40,   41,   42,   34,   43,   44,   45,   46,   46,   47,
       48,   49,   50,   41,   34,   34,   51,   51,   51,   51,
       52,   34,   34,   51,   51,   51,   51,   51,   51,   51,
       51,   51,   51,   51,   51,   51,   51,   51,   51,   51,
       51,   51,   51,   51,   51,   51,   51,   53,   54,   41,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   57,   57,  150,  153,  153,  153,  151,   58,
       58,   59,  155,   61,   59,   62,  150,   73,   63,   74,
      151,   73,   60,   74,  156,   75,   60,  178,  178,   75,

       77,   36,   77,   78,   77,  285,   77,   36,   77,   78,
       77,   79,   64,   83,   80,   85,  286,   79,   81,  598,
       80,  184,   85,   86,   81,   87,  175,  175,  175,   82,
       86,  183,   87,  250,  250,   82,  177,  177,  177,  315,
      315,   59,   59,   59,   59,   65,   66,   67,   68,   69,
       70,   71,   72,   59,  187,   61,   59,   62,  188,   59,
       63,   60,  597,   59,   89,   60,   90,   91,   89,  195,
       90,   91,   92,   88,  189,  596,   92,  180,  180,  180,
       88,   59,  190,   60,   64,  196,   89,  150,   60,   91,
      191,  151,   60,  338,   92,  216,   59,   59,   60,   60,

      339,   89,   60,  150,   91,  217,   98,  151,  235,   92,
       60,  232,  236,   59,   59,   59,   59,   65,   66,   67,
       68,   69,   70,   71,   72,   60,   60,  233,   59,  218,
      234,  469,   59,   59,  219,   60,  523,  184,   89,  220,
       93,   91,  595,   99,  237,  100,   92,  183,   60,   59,
       59,   60,   94,  238,   60,   99,  342,  100,   98,  343,
       60,  594,   60,  278,  192,   59,   59,  279,  102,  102,
      103,  103,  101,  104,  104,  106,  193,  107,   60,  280,
       60,  301,  340,  108,  101,  302,  194,  224,   95,  341,
       96,  225,  593,  290,  153,  153,  153,  105,  105,  195,

      226,  228,   59,   59,  105,   60,  592,  154,   89,  291,
       93,   91,   59,  346,  229,  196,   92,  190,   59,  230,
      321,  106,   94,  107,   59,  191,   60,  591,  322,  108,
      347,  590,   60,  154,  153,  153,  153,   59,   59,  198,
      199,  198,  200,  198,   59,  119,   36,  119,  120,  119,
      105,  211,  211,  211,  212,  211,  121,  192,   95,  122,
       96,  589,  588,  119,   36,  119,  120,  119,  587,  193,
      123,  586,   59,   59,  121,   60,  585,  122,   89,  194,
       93,   91,  239,  175,  175,  175,   92,  175,  175,  175,
       59,  240,   94,  203,  204,  203,  205,  203,  584,  583,

      241,  582,   60,  175,  175,  175,  295,  213,  254,  254,
      254,  255,  255,  255,  247,  247,  247,  256,  256,  256,
      175,  175,  175,  206,  247,  581,  296,  187,   95,  381,
       97,  188,  247,  247,  247,  247,  247,  247,  580,  297,
      394,  409,   59,   59,  579,   60,  578,  189,   89,  381,
       93,   91,  175,  175,  175,  577,   92,  251,  251,  251,
      394,  410,   94,  252,  252,  252,  599,  251,  175,  175,
      175,  576,   60,  252,  574,  251,  251,  251,  251,  251,
      251,  252,  252,  252,  252,  252,  252,  253,  253,  253,
      257,  258,  257,  259,  257,  206,  572,  253,   95,  571,

       97,  436,  436,  436,  570,  253,  253,  253,  253,  253,
      253,  569,   59,  109,  110,   36,  110,  111,  110,  109,
      109,  109,  109,  109,  109,  112,  109,  113,  114,  115,
      115,  115,  109,  109,  109,  109,  109,  109,  109,  113,
      113,  113,  113,  109,  109,  116,  113,  113,  113,  113,
      113,  113,  113,  113,  113,  113,  113,  113,  113,  113,
      113,  113,  113,  113,  113,  113,  113,  113,  113,  113,
      109,  109,  109,  109,  109,  109,  109,  109,  109,  109,
      109,  109,  109,  109,  109,  126,  413,  433,  442,  568,
      127,  260,  261,  260,  262,  260,  469,  565,  542,  564,

      128,  523,  127,  127,  127,  127,  413,  434,  443,  127,
      127,  129,  130,  131,  132,  133,  134,  127,  135,  127,
      136,  137,  138,  139,  140,  127,  141,  142,  143,  144,
      145,  127,  146,  147,  124,  263,  264,  263,  265,  263,
      124,  469,  124,  470,  471,  561,  560,  148,  148,  559,
      149,  149,  149,  124,  558,  436,  436,  436,  124,  124,
      149,  149,  149,  149,  557,  124,  124,  149,  149,  149,
      149,  149,  149,  149,  149,  149,  149,  149,  149,  149,
      149,  149,  149,  149,  149,  149,  149,  149,  149,  149,
      149,  472,  556,  555,  124,  124,  124,  124,  124,  124,

      124,  124,  124,  124,  124,  124,  162,  551,  552,  163,
      554,  473,  163,  266,  267,  266,  268,  266,  164,  164,
      198,  199,  198,  200,  198,  553,  163,  552,  552,  573,
      165,  550,  549,  163,  548,  547,  166,  167,  546,  545,
      544,  168,  270,  204,  270,  271,  270,  543,  169,  573,
      523,  541,  170,  540,  171,  172,  173,  174,  273,  274,
      273,  275,  273,  211,  211,  211,  212,  211,  316,  316,
      316,  539,  538,  537,  317,  317,  317,  536,  316,  257,
      258,  257,  259,  257,  317,  535,  316,  316,  316,  316,
      316,  316,  317,  317,  317,  317,  317,  317,  534,  533,

      532,  531,  253,  253,  253,  260,  261,  260,  262,  260,
      530,  529,  253,  263,  264,  263,  265,  263,  528,  213,
      253,  253,  253,  253,  253,  253,  266,  267,  266,  268,
      266,  198,  199,  198,  200,  198,  270,  204,  270,  271,
      270,  270,  204,  270,  271,  270,  273,  274,  273,  275,
      273,  362,  362,  362,  527,  526,  525,  363,  363,  363,
      524,  362,  575,  575,  575,  575,  575,  363,  523,  362,
      362,  362,  362,  362,  362,  363,  363,  363,  363,  363,
      363,  403,  403,  403,  521,  520,  519,  404,  404,  404,
      518,  403,  575,  575,  575,  575,  575,  404,  517,  403,

      403,  403,  403,  403,  403,  404,  404,  404,  404,  404,
      404,  252,  252,  252,  458,  458,  458,  458,  458,  516,
      515,  252,  458,  458,  458,  458,  458,  514,  513,  252,
      252,  252,  252,  252,  252,  459,  562,  562,  562,  562,
      562,  512,  511,  459,  566,  566,  566,  566,  566,  562,
      562,  562,  562,  562,  510,  509,  508,  563,  566,  566,
      566,  566,  566,  507,  506,  567,  505,  504,  503,  502,
      563,  501,  500,  499,  469,  498,  497,  496,  495,  567,
       56,   56,   56,   56,   56,   56,   56,   56,   56,   56,
       56,   56,   60,   60,   60,   60,   60,   60,   60,   60,

       60,   60,   60,   60,   76,   76,   76,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   84,   84,   84,   84,
       84,   84,   84,   84,   84,   84,   84,   84,  118,  118,
      118,  118,  118,  118,  118,  118,  118,  118,  118,  118,
      124,  494,  493,  492,  124,  124,  491,  124,  490,  489,
      488,  124,  152,  152,  149,  149,  149,  161,  161,  161,
      161,  161,  161,  161,  161,  161,  161,  161,  161,  179,
      179,  179,  179,  179,  179,  183,  183,  183,  183,  183,
      183,  183,  183,  183,  487,  183,  183,  202,  202,  202,
      202,  202,  202,  202,  202,  202,  202,  208,  486,  485,

      208,  208,  484,  483,  208,  208,  208,  208,  209,  209,
      209,  210,  210,  210,  245,  245,  482,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  246,  246,  246,  522,
      522,  481,  522,  522,  522,  522,  522,  522,  522,  522,
      522,  480,  479,  478,  477,  476,  475,  474,  468,  467,
      466,  465,  464,  463,  462,  461,  460,  457,  456,  455,
      454,  453,  452,  451,  450,  449,  448,  447,  446,  445,
      444,  441,  440,  439,  438,  437,  435,  432,  431,  430,
      429,  428,  427,  426,  425,  424,  423,  422,  421,  420,
      419,  418,  417,  416,  415,  414,  412,  411,  408,  407,

      406,  405,  402,  401,  400,  399,  398,  397,  396,  395,
      393,  392,  391,  390,  389,  388,  387,  386,  385,  384,
      383,  382,  380,  379,  378,  377,  376,  375,  374,  373,
      372,  371,  370,  369,  368,  367,  366,  365,  364,  361,
      360,  359,  358,  357,  356,  355,  354,  353,  352,  351,
      350,  349,  348,  345,  344,  337,  336,  335,  334,  333,
      332,  331,  330,  329,  328,  327,  326,  325,  324,  323,
      320,  319,  318,  274,  204,  267,  264,  261,  258,  314,
      313,  312,  311,  310,  309,  308,  307,  306,  305,  304,
      303,  300,  299,  298,  294,  293,  292,  289,  288,  287,

      284,  283,  282,  281,  277,  276,  211,  204,  272,  199,
      269,  185,  184,  161,  249,  248,  244,  243,  242,  231,
      227,  223,  222,  221,  215,  214,  157,  125,  157,  125,
      207,  201,  197,  186,  184,  185,  184,  157,  125,  182,
      181,  176,  160,  159,  158,  157,  125,  599,  117,   55,
       33,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,

      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599
    } ;

static const flex_int16_t yy_chk[1424] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    3,    4,   44,   46,   46,   46,   44,    3,
        4,    5,   49,    5,    5,    5,   80,    7,    5,    7,
       80,    8,    7,    8,   49,    7,    8,   68,   68,    8,

        9,    9,    9,    9,    9,  221,   10,   10,   10,   10,
       10,    9,    5,   10,    9,   11,  221,   10,    9,  597,
       10,   85,   12,   11,   10,   11,   65,   65,   65,    9,
       12,   85,   12,  164,  164,   10,   67,   67,   67,  250,
      250,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    6,   92,    6,    6,    6,   92,   13,
        6,   13,  596,   14,   13,   14,   13,   13,   14,   98,
       14,   14,   13,   11,   92,  595,   14,   70,   70,   70,
       12,   17,   93,   17,    6,   98,   17,  114,   13,   17,
       93,  114,   14,  295,   17,  131,   18,   21,   18,   21,

      295,   18,   21,  122,   18,  131,   21,  122,  141,   18,
       17,  140,  141,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,   18,   21,  140,   13,  132,
      140,  542,   14,   15,  132,   15,  542,  184,   15,  132,
       15,   15,  594,   23,  142,   23,   15,  184,   23,   22,
       17,   22,   15,  142,   22,   24,  297,   24,   22,  297,
       24,  593,   15,  216,   94,   18,   21,  216,   25,   26,
       25,   26,   23,   25,   26,   27,   94,   27,   22,  216,
       27,  233,  296,   27,   24,  233,   94,  136,   15,  296,
       15,  136,  591,  225,   45,   45,   45,   25,   26,  267,

      136,  138,   15,   16,   27,   16,  590,   45,   16,  225,
       16,   16,   23,  300,  138,  267,   16,  261,   22,  138,
      279,   28,   16,   28,   24,  261,   28,  589,  279,   28,
      300,  588,   16,   45,  153,  153,  153,   25,   26,  101,
      101,  101,  101,  101,   27,   31,   31,   31,   31,   31,
       28,  128,  128,  128,  128,  128,   31,  264,   16,   31,
       16,  587,  584,   32,   32,   32,   32,   32,  583,  264,
       32,  582,   16,   19,   32,   19,  581,   32,   19,  264,
       19,   19,  143,  176,  176,  176,   19,  177,  177,  177,
       28,  143,   19,  105,  105,  105,  105,  105,  579,  578,

      143,  577,   19,  178,  178,  178,  229,  128,  179,  179,
      179,  180,  180,  180,  154,  154,  154,  181,  181,  181,
      254,  254,  254,  105,  154,  576,  229,  258,   19,  337,
       19,  258,  154,  154,  154,  154,  154,  154,  574,  229,
      350,  371,   19,   20,  573,   20,  570,  258,   20,  337,
       20,   20,  255,  255,  255,  569,   20,  165,  165,  165,
      350,  371,   20,  172,  172,  172,  274,  165,  256,  256,
      256,  568,   20,  172,  565,  165,  165,  165,  165,  165,
      165,  172,  172,  172,  172,  172,  172,  174,  174,  174,
      189,  189,  189,  189,  189,  274,  561,  174,   20,  560,

       20,  402,  402,  402,  553,  174,  174,  174,  174,  174,
      174,  552,   20,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   39,  374,  399,  411,  551,
       39,  191,  191,  191,  191,  191,  523,  549,  523,  548,

       39,  523,   39,   39,   39,   39,  374,  399,  411,   39,
       39,   39,   39,   39,   39,   39,   39,   39,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   39,   39,   39,
       39,   39,   39,   39,   43,  194,  194,  194,  194,  194,
       43,  436,   43,  436,  436,  546,  545,   43,   43,  544,
       43,   43,   43,   43,  543,  436,  436,  436,   43,   43,
       43,   43,   43,   43,  541,   43,   43,   43,   43,   43,
       43,   43,   43,   43,   43,   43,   43,   43,   43,   43,
       43,   43,   43,   43,   43,   43,   43,   43,   43,   43,
       43,  437,  540,  539,   43,   43,   43,   43,   43,   43,

       43,   43,   43,   43,   43,   43,   64,  534,  535,   64,
      537,  437,   64,  196,  196,  196,  196,  196,   64,   64,
      198,  198,  198,  198,  198,  536,   64,  534,  535,  564,
       64,  533,  532,   64,  530,  529,   64,   64,  528,  527,
      525,   64,  203,  203,  203,  203,  203,  524,   64,  564,
      522,  521,   64,  520,   64,   64,   64,   64,  206,  206,
      206,  206,  206,  211,  211,  211,  211,  211,  251,  251,
      251,  519,  518,  517,  252,  252,  252,  516,  251,  257,
      257,  257,  257,  257,  252,  515,  251,  251,  251,  251,
      251,  251,  252,  252,  252,  252,  252,  252,  514,  513,

      510,  509,  253,  253,  253,  260,  260,  260,  260,  260,
      508,  507,  253,  263,  263,  263,  263,  263,  504,  211,
      253,  253,  253,  253,  253,  253,  266,  266,  266,  266,
      266,  269,  269,  269,  269,  269,  270,  270,  270,  270,
      270,  272,  272,  272,  272,  272,  273,  273,  273,  273,
      273,  316,  316,  316,  503,  502,  501,  317,  317,  317,
      500,  316,  567,  567,  567,  567,  567,  317,  499,  316,
      316,  316,  316,  316,  316,  317,  317,  317,  317,  317,
      317,  362,  362,  362,  498,  497,  495,  363,  363,  363,
      494,  362,  575,  575,  575,  575,  575,  363,  493,  362,

      362,  362,  362,  362,  362,  363,  363,  363,  363,  363,
      363,  403,  403,  403,  426,  426,  426,  426,  426,  492,
      489,  403,  458,  458,  458,  458,  458,  487,  486,  403,
      403,  403,  403,  403,  403,  426,  547,  547,  547,  547,
      547,  485,  484,  458,  550,  550,  550,  550,  550,  562,
      562,  562,  562,  562,  482,  481,  480,  547,  566,  566,
      566,  566,  566,  479,  478,  550,  477,  476,  475,  474,
      562,  473,  472,  471,  470,  467,  466,  465,  463,  566,
      600,  600,  600,  600,  600,  600,  600,  600,  600,  600,
      600,  600,  601,  601,  601,  601,  601,  601,  601,  601,

      601,  601,  601,  601,  602,  602,  602,  602,  602,  602,
      602,  602,  602,  602,  602,  602,  603,  603,  603,  603,
      603,  603,  603,  603,  603,  603,  603,  603,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  604,  604,  604,
      605,  461,  460,  457,  605,  605,  456,  605,  455,  454,
      453,  605,  606,  606,  607,  607,  607,  608,  608,  608,
      608,  608,  608,  608,  608,  608,  608,  608,  608,  609,
      609,  609,  609,  609,  609,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  452,  610,  610,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  612,  451,  450,

      612,  612,  449,  448,  612,  612,  612,  612,  613,  613,
      613,  614,  614,  614,  615,  615,  447,  615,  615,  615,
      615,  615,  615,  615,  615,  615,  616,  616,  616,  617,
      617,  446,  617,  617,  617,  617,  617,  617,  617,  617,
      617,  445,  444,  443,  442,  441,  440,  439,  435,  434,
      433,  432,  431,  430,  429,  428,  427,  425,  424,  423,
      422,  421,  420,  419,  418,  417,  416,  415,  414,  413,
      412,  410,  409,  408,  407,  406,  401,  397,  395,  394,
      393,  392,  391,  389,  387,  386,  385,  384,  383,  382,
      381,  379,  378,  377,  376,  375,  373,  372,  368,  367,

      366,  364,  361,  359,  358,  356,  354,  353,  352,  351,
      349,  348,  347,  346,  345,  344,  343,  342,  341,  340,
      339,  338,  336,  335,  334,  332,  331,  330,  329,  328,
      327,  326,  325,  324,  323,  322,  321,  320,  318,  314,
      313,  312,  311,  310,  309,  308,  307,  306,  305,  304,
      303,  302,  301,  299,  298,  294,  293,  292,  291,  290,
      289,  288,  287,  286,  285,  284,  283,  282,  281,  280,
      278,  277,  276,  275,  271,  268,  265,  262,  259,  249,
      244,  243,  242,  241,  240,  239,  238,  237,  236,  235,
      234,  232,  231,  230,  228,  227,  226,  224,  223,  222,

      220,  219,  218,  217,  215,  214,  212,  205,  204,  200,
      199,  185,  183,  162,  157,  155,  146,  145,  144,  139,
      137,  135,  134,  133,  130,  129,  123,  120,  117,  111,
      107,  103,  100,   90,   88,   86,   84,   83,   78,   74,
       71,   66,   62,   58,   57,   55,   37,   33,   30,    2,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,

      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599,  599,  599,  599,  599,  599,  599,  599,
      599,  599,  599
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 1;

static const flex_int16_t yy_rule_linenum[127] =
    {   0,
      198,  201,  202,  203,  209,  227,  228,  229,  230,  231,
      232,  233,  234,  235,  236,  237,  238,  239,  240,  241,
      242,  243,  244,  245,  246,  247,  248,  249,  250,  251,
      252,  253,  254,  255,  256,  257,  258,  259,  260,  261,
      262,  263,  264,  265,  266,  267,  271,  275,  279,  282,
      283,  284,  285,  286,  287,  288,  289,  290,  292,  296,
      297,  298,  299,  301,  308,  309,  313,  318,  321,  324,
      327,  335,  342,  343,  344,  350,  357,  364,  384,  394,
      409,  415,  434,  447,  463,  478,  495,  496,  507,  518,
      519,  531,  540,  550,  569,  581,  595,  596,  607,  617,

      627,  628,  629,  630,  631,  632,  633,  636,  638,  646,
      664,  669,  670,  676,  677,  688,  694,  700,  706,  722,
      723,  727,  734,  750,  770,  809
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "/Users/akim/src/gnu/bison/src/scan-gram.l"
/* Bison Grammar Scanner                             -*- C -*-

   Copyright (C) 2002-2015, 2018-2020 Free Software Foundation, Inc.

   This file is part of Bison, the GNU Compiler Compiler.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
#define YY_NO_INPUT 1
#line 24 "/Users/akim/src/gnu/bison/src/scan-gram.l"
#include <errno.h>

#include <c-ctype.h>
#include <mbswidth.h>
#include <quote.h>
#include <quotearg.h>

#include <src/complain.h>
#include <src/files.h>
#include <src/getargs.h>
#include <src/gram.h>
#include <src/reader.h>
#include <src/scan-gram.h>
#include <src/uniqstr.h>

#define FLEX_PREFIX(Id) gram_ ## Id
#include <src/flex-scanner.h>

/* Work around a bug in flex 2.5.31.  See Debian bug 333231
   <http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=333231>.  */
#undef gram_wrap
#define gram_wrap() 1

#define YY_DECL GRAM_LEX_DECL

/* Location of scanner cursor.  */
static boundary scanner_cursor;

#define YY_USER_ACTION  location_compute (loc, &scanner_cursor, yytext, yyleng);

/* Report that yytext is an extension, and evaluate to its token type.  */
#define BISON_DIRECTIVE(Directive)                              \
  (bison_directive (loc, yytext), PERCENT_ ## Directive)

#define RETURN_PERCENT_PARAM(Value)             \
  RETURN_VALUE(PERCENT_PARAM, param_ ## Value)

#define RETURN_PERCENT_FLAG(Value)                      \
  RETURN_VALUE(PERCENT_FLAG, uniqstr_new (Value))

#define RETURN_VALUE(Token, Value)              \
  do {                                          \
    val->Token = Value;                         \
    return Token;                               \
  } while (0)

#define ROLLBACK_CURRENT_TOKEN                                  \
  do {                                                          \
    scanner_cursor.column -= mbsnwidth (yytext, yyleng, 0);     \
    scanner_cursor.byte -= yyleng;                              \
    yyless (0);                                                 \
  } while (0)

#define DEPRECATED(Msg)                                         \
  do {                                                          \
    deprecated_directive (loc, yytext, Msg);                    \
    scanner_cursor.column -= mbsnwidth (Msg, strlen (Msg), 0);  \
    scanner_cursor.byte -= strlen (Msg);                        \
    for (size_t i = strlen (Msg); i != 0; --i)                  \
      unput (Msg[i - 1]);                                       \
  } while (0)

/* The current file name.  Might change with #line.  */
static uniqstr current_file = NULL;

/* A string representing the most recently saved token.  */
static char *last_string = NULL;

/* Bracketed identifier. */
static uniqstr bracketed_id_str = NULL;
static location bracketed_id_loc;
static boundary bracketed_id_start;
static int bracketed_id_context_state = 0;

void
gram_scanner_last_string_free (void)
{
  STRING_FREE;
}

static void handle_syncline (char *, location);
static int scan_integer (char const *p, int base, location loc);
static int convert_ucn_to_byte (char const *hex_text);
static void unexpected_eof (boundary, char const *);
static void unexpected_newline (boundary, char const *);

#line 1422 "src/scan-gram.c"
#line 112 "/Users/akim/src/gnu/bison/src/scan-gram.l"
 /* A C-like comment in directives/rules. */

 /* Strings and characters in directives/rules. */

 /* A identifier was just read in directives/rules.  Special state
    to capture the sequence 'identifier :'. */

 /* POSIX says that a tag must be both an id and a C union member, but
    historically almost any character is allowed in a tag.  We
    disallow NUL, as this simplifies our implementation.  We match
    angle brackets in nested pairs: several languages use them for
    generics/template types.  */

 /* Four types of user code:
    - prologue (code between '%{' '%}' in the first section, before %%);
    - actions, printers, union, etc, (between braced in the middle section);
    - epilogue (everything after the second %%).
    - predicate (code between '%?{' and '{' in middle section); */

 /* C and C++ comments in code. */

 /* Strings and characters in code. */

 /* Bracketed identifiers support. */

 /* UTF-8 Encoded Unicode Code Point, from Flex's documentation. */
/* Zero or more instances of backslash-newline.  Following GCC, allow
   white space between the backslash and the newline.  */
/* An equal sign, with optional leading whitespaces. This is used in some
   deprecated constructs. */
#line 1454 "src/scan-gram.c"

#define INITIAL 0
#define SC_YACC_COMMENT 1
#define SC_ESCAPED_STRING 2
#define SC_ESCAPED_CHARACTER 3
#define SC_AFTER_IDENTIFIER 4
#define SC_TAG 5
#define SC_PROLOGUE 6
#define SC_BRACED_CODE 7
#define SC_EPILOGUE 8
#define SC_PREDICATE 9
#define SC_COMMENT 10
#define SC_LINE_COMMENT 11
#define SC_STRING 12
#define SC_CHARACTER 13
#define SC_BRACKETED_ID 14
#define SC_RETURN_BRACKETED_ID 15

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
/* %if-c-only */
#include <unistd.h>
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* %if-c-only Reentrant structure and macros (non-C++). */
/* %if-reentrant */
/* %if-c-only */

static int yy_init_globals ( void );

/* %endif */
/* %if-reentrant */
/* %endif */
/* %endif End reentrant structures and macros. */

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* %if-bison-bridge */
/* %endif */

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

/* %not-for-header */
#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif
/* %ok-for-header */

/* %endif */

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif
/* %ok-for-header */

/* %endif */
#endif

/* %if-c-only */

/* %endif */

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* %if-c-only Standard (non-C++) definition */
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
/* %% [5.0] fread()/read() definition of YY_INPUT goes here unless we're doing C++ \ */\
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\
/* %if-c++-only C++ definition \ */\
/* %endif */

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
/* %if-c-only */
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

/* %if-tables-serialization structures and prototypes */
/* %not-for-header */
/* %ok-for-header */

/* %not-for-header */
/* %tables-yydmap generated elements */
/* %endif */
/* end tables serialization structures and prototypes */

/* %ok-for-header */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
/* %if-c-only Standard (non-C++) definition */

extern int yylex (void);

#define YY_DECL int yylex (void)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

/* %% [6.0] YY_RULE_SETUP definition goes here */
#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/* %not-for-header */
/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
/* %if-c-only */
			yyin = stdin;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! yyout )
/* %if-c-only */
			yyout = stdout;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
/* %% [7.0] user's declarations go here */
#line 159 "/Users/akim/src/gnu/bison/src/scan-gram.l"


  /* Nesting level.  Either for nested braces, or nested angle brackets
     (but not mixed).  */
  int nesting PACIFY_CC (= 0);

  /* Parent context state, when applicable.  */
  int context_state PACIFY_CC (= 0);

  /* Location of most recent identifier, when applicable.  */
  location id_loc PACIFY_CC (= empty_loc);

  /* Where containing code started, when applicable.  Its initial
     value is relevant only when yylex is invoked in the SC_EPILOGUE
     start condition.  */
  boundary code_start = scanner_cursor;

  /* Where containing comment or string or character literal started,
     when applicable.  */
  boundary token_start PACIFY_CC (= scanner_cursor);

  /* We cannot trust YY_USER_INIT, whose semantics changes over time
     (it moved in Flex 2.5.38).  */
  static bool first = true;
  if (first)
    {
      scanner_cursor = loc->start;
      first = false;
    }



  /*-----------------------.
  | Scanning white space.  |
  `-----------------------*/

#line 1789 "src/scan-gram.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
/* %% [8.0] yymore()-related code goes here */
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

/* %% [9.0] code to set up and find next match goes here */
		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 600 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 599 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
/* %% [10.0] code to find the action number goes here */
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

/* %% [11.0] code for yylineno update goes here */

do_action:	/* This label is used only to access EOF actions. */

/* %% [12.0] debug code goes here */
		if ( yy_flex_debug )
			{
			if ( yy_act == 0 )
				fprintf( stderr, "--scanner backing up\n" );
			else if ( yy_act < 127 )
				fprintf( stderr, "--accepting rule at line %ld (\"%s\")\n",
				         (long)yy_rule_linenum[yy_act], yytext );
			else if ( yy_act == 127 )
				fprintf( stderr, "--accepting default rule (\"%s\")\n",
				         yytext );
			else if ( yy_act == 128 )
				fprintf( stderr, "--(end of buffer or a NUL)\n" );
			else
				fprintf( stderr, "--EOF (start condition %d)\n", YY_START );
			}

		switch ( yy_act )
	{ /* beginning of action switch */
/* %% [13.0] actions go here */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

/* Comments and white space.  */
case 1:
YY_RULE_SETUP
#line 198 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
     complain (loc, Wother, _("stray ',' treated as white space"));
  }
	YY_BREAK
case 2:
/* rule 2 can match eol */
#line 202 "/Users/akim/src/gnu/bison/src/scan-gram.l"
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 202 "/Users/akim/src/gnu/bison/src/scan-gram.l"
continue;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 203 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    token_start = loc->start;
    context_state = YY_START;
    BEGIN SC_YACC_COMMENT;
  }
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 209 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    handle_syncline (yytext + sizeof "#line " - 1, *loc);
  }
	YY_BREAK

/*----------------------------.
  | Scanning Bison directives.  |
  `----------------------------*/
/* For directives that are also command line options, the regex must be
        "%..."
     after "[-_]"s are removed, and the directive must match the --long
     option name, with a single string argument.  Otherwise, add exceptions
     to ../build-aux/cross-options.pl.  */


case 6:
YY_RULE_SETUP
#line 227 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (NONASSOC);
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 228 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (CODE);
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 229 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_PERCENT_FLAG ("parse.trace");
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 230 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (DEFAULT_PREC);
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 231 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (DEFINE);
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 232 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (DEFINES);
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 233 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (DESTRUCTOR);
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 234 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (DPREC);
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 235 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (EMPTY);
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 236 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (EXPECT);
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 237 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (EXPECT_RR);
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 238 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (PERCENT_FILE_PREFIX, uniqstr_new (yytext));
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 239 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (INITIAL_ACTION);
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 240 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (GLR_PARSER);
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 241 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (LANGUAGE);
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 242 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_LEFT;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 243 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_PERCENT_PARAM (lex);
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 244 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_PERCENT_FLAG ("locations");
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 245 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (MERGE);
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 246 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (NO_DEFAULT_PREC);
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 247 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (NO_LINES);
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 248 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_NONASSOC;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 249 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (NONDETERMINISTIC_PARSER);
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 250 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (NTERM);
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 251 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (OUTPUT);
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 252 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_PERCENT_PARAM (both);
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 253 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_PERCENT_PARAM (parse);
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 254 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_PREC;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 255 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (PRECEDENCE);
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 256 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (PRINTER);
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 257 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (REQUIRE);
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 258 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_RIGHT;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 259 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (SKELETON);
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 260 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_START;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 261 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (TOKEN);
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 262 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_TOKEN;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 263 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (TOKEN_TABLE);
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 264 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_TYPE;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 265 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_UNION;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 266 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (VERBOSE);
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 267 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_YACC;
	YY_BREAK
/* Deprecated since Bison 2.3b (2008-05-27), but the warning is
     issued only since Bison 3.4. */
case 47:
YY_RULE_SETUP
#line 271 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (PERCENT_PURE_PARSER, uniqstr_new (yytext));
	YY_BREAK
/* Deprecated since Bison 3.0 (2013-07-25), but the warning is
     issued only since Bison 3.3. */
case 48:
YY_RULE_SETUP
#line 275 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (PERCENT_ERROR_VERBOSE, uniqstr_new (yytext));
	YY_BREAK
/* Deprecated since Bison 2.6 (2012-07-19), but the warning is
     issued only since Bison 3.3. */
case 49:
/* rule 49 can match eol */
YY_RULE_SETUP
#line 279 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (PERCENT_NAME_PREFIX, uniqstr_new (yytext));
	YY_BREAK
/* Deprecated since Bison 2.7.90, 2012. */
case 50:
YY_RULE_SETUP
#line 282 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED ("%default-prec");
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 283 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (PERCENT_ERROR_VERBOSE, uniqstr_new (yytext));
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 284 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED ("%expect-rr");
	YY_BREAK
case 53:
/* rule 53 can match eol */
YY_RULE_SETUP
#line 285 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (PERCENT_FILE_PREFIX, uniqstr_new (yytext));
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 286 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED ("%output \"y.tab.c\"");
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 287 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED ("%no-default-prec");
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 288 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED ("%no-lines");
	YY_BREAK
case 57:
/* rule 57 can match eol */
YY_RULE_SETUP
#line 289 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED ("%output");
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 290 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED ("%token-table");
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 292 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    complain (loc, complaint, _("invalid directive: %s"), quote (yytext));
  }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 296 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return COLON;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 297 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return EQUAL;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 298 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PIPE;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 299 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return SEMICOLON;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 301 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    val->ID = uniqstr_new (yytext);
    id_loc = *loc;
    bracketed_id_str = NULL;
    BEGIN SC_AFTER_IDENTIFIER;
  }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 308 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (INT, scan_integer (yytext, 10, *loc));
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 309 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (INT, scan_integer (yytext, 16, *loc));
	YY_BREAK
/* Identifiers may not start with a digit.  Yet, don't silently
     accept "1FOO" as "1 FOO".  */
case 67:
YY_RULE_SETUP
#line 313 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    complain (loc, complaint, _("invalid identifier: %s"), quote (yytext));
  }
	YY_BREAK
/* Characters.  */
case 68:
YY_RULE_SETUP
#line 318 "/Users/akim/src/gnu/bison/src/scan-gram.l"
token_start = loc->start; BEGIN SC_ESCAPED_CHARACTER;
	YY_BREAK
/* Strings. */
case 69:
YY_RULE_SETUP
#line 321 "/Users/akim/src/gnu/bison/src/scan-gram.l"
token_start = loc->start; BEGIN SC_ESCAPED_STRING;
	YY_BREAK
/* Prologue. */
case 70:
YY_RULE_SETUP
#line 324 "/Users/akim/src/gnu/bison/src/scan-gram.l"
code_start = loc->start; BEGIN SC_PROLOGUE;
	YY_BREAK
/* Code in between braces.  */
case 71:
YY_RULE_SETUP
#line 327 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW;
    nesting = 0;
    code_start = loc->start;
    BEGIN SC_BRACED_CODE;
  }
	YY_BREAK
/* Semantic predicate. */
case 72:
/* rule 72 can match eol */
YY_RULE_SETUP
#line 335 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    nesting = 0;
    code_start = loc->start;
    BEGIN SC_PREDICATE;
  }
	YY_BREAK
/* A type. */
case 73:
YY_RULE_SETUP
#line 342 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return TAG_ANY;
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 343 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return TAG_NONE;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 344 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    nesting = 0;
    token_start = loc->start;
    BEGIN SC_TAG;
  }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 350 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    static int percent_percent_count;
    if (++percent_percent_count == 2)
      BEGIN SC_EPILOGUE;
    return PERCENT_PERCENT;
  }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 357 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    bracketed_id_str = NULL;
    bracketed_id_start = loc->start;
    bracketed_id_context_state = YY_START;
    BEGIN SC_BRACKETED_ID;
  }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 364 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    complain (loc, complaint, "%s: %s",
              ngettext ("invalid character", "invalid characters", yyleng),
              quote_mem (yytext, yyleng));
  }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
#line 370 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    loc->start = loc->end = scanner_cursor;
    yyterminate ();
  }
	YY_BREAK

/*--------------------------------------------------------------.
  | Supporting \0 complexifies our implementation for no expected |
  | added value.                                                  |
  `--------------------------------------------------------------*/


case 79:
YY_RULE_SETUP
#line 384 "/Users/akim/src/gnu/bison/src/scan-gram.l"
complain (loc, complaint, _("invalid null character"));
	YY_BREAK

/*-----------------------------------------------------------------.
  | Scanning after an identifier, checking whether a colon is next.  |
  `-----------------------------------------------------------------*/


case 80:
YY_RULE_SETUP
#line 394 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    if (bracketed_id_str)
      {
        ROLLBACK_CURRENT_TOKEN;
        BEGIN SC_RETURN_BRACKETED_ID;
        *loc = id_loc;
        return ID;
      }
    else
      {
        bracketed_id_start = loc->start;
        bracketed_id_context_state = YY_START;
        BEGIN SC_BRACKETED_ID;
      }
  }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 409 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    ROLLBACK_CURRENT_TOKEN;
    BEGIN (bracketed_id_str ? SC_RETURN_BRACKETED_ID : INITIAL);
    *loc = id_loc;
    return ID_COLON;
  }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 415 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    ROLLBACK_CURRENT_TOKEN;
    BEGIN (bracketed_id_str ? SC_RETURN_BRACKETED_ID : INITIAL);
    *loc = id_loc;
    return ID;
  }
	YY_BREAK
case YY_STATE_EOF(SC_AFTER_IDENTIFIER):
#line 421 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    BEGIN (bracketed_id_str ? SC_RETURN_BRACKETED_ID : INITIAL);
    *loc = id_loc;
    return ID;
  }
	YY_BREAK

/*--------------------------------.
  | Scanning bracketed identifiers. |
  `--------------------------------*/


case 83:
YY_RULE_SETUP
#line 434 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    if (bracketed_id_str)
      {
        complain (loc, complaint,
                  _("unexpected identifier in bracketed name: %s"),
                  quote (yytext));
      }
    else
      {
        bracketed_id_str = uniqstr_new (yytext);
        bracketed_id_loc = *loc;
      }
  }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 447 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    BEGIN bracketed_id_context_state;
    if (bracketed_id_str)
      {
        if (INITIAL == bracketed_id_context_state)
          {
            val->BRACKETED_ID = bracketed_id_str;
            bracketed_id_str = 0;
            *loc = bracketed_id_loc;
            return BRACKETED_ID;
          }
      }
    else
      complain (loc, complaint, _("an identifier expected"));
  }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 463 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    complain (loc, complaint, "%s: %s",
              ngettext ("invalid character in bracketed name",
                        "invalid characters in bracketed name", yyleng),
              quote_mem (yytext, yyleng));
  }
	YY_BREAK
case YY_STATE_EOF(SC_BRACKETED_ID):
#line 470 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    BEGIN bracketed_id_context_state;
    unexpected_eof (bracketed_id_start, "]");
  }
	YY_BREAK



case 86:
YY_RULE_SETUP
#line 478 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    ROLLBACK_CURRENT_TOKEN;
    val->BRACKETED_ID = bracketed_id_str;
    bracketed_id_str = 0;
    *loc = bracketed_id_loc;
    BEGIN INITIAL;
    return BRACKETED_ID;
  }
	YY_BREAK

/*---------------------------------------------------------------.
  | Scanning a Yacc comment.  The initial '/ *' is already eaten.  |
  `---------------------------------------------------------------*/


case 87:
YY_RULE_SETUP
#line 495 "/Users/akim/src/gnu/bison/src/scan-gram.l"
BEGIN context_state;
	YY_BREAK
case 88:
/* rule 88 can match eol */
YY_RULE_SETUP
#line 496 "/Users/akim/src/gnu/bison/src/scan-gram.l"
continue;
	YY_BREAK
case YY_STATE_EOF(SC_YACC_COMMENT):
#line 497 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "*/"); BEGIN context_state;
	YY_BREAK

/*------------------------------------------------------------.
  | Scanning a C comment.  The initial '/ *' is already eaten.  |
  `------------------------------------------------------------*/


case 89:
/* rule 89 can match eol */
YY_RULE_SETUP
#line 507 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW; BEGIN context_state;
	YY_BREAK
case YY_STATE_EOF(SC_COMMENT):
#line 508 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "*/"); BEGIN context_state;
	YY_BREAK

/*--------------------------------------------------------------.
  | Scanning a line comment.  The initial '//' is already eaten.  |
  `--------------------------------------------------------------*/


case 90:
/* rule 90 can match eol */
YY_RULE_SETUP
#line 518 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW; BEGIN context_state;
	YY_BREAK
case 91:
/* rule 91 can match eol */
YY_RULE_SETUP
#line 519 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW;
	YY_BREAK
case YY_STATE_EOF(SC_LINE_COMMENT):
#line 520 "/Users/akim/src/gnu/bison/src/scan-gram.l"
BEGIN context_state;
	YY_BREAK

/*------------------------------------------------.
  | Scanning a Bison string, including its escapes. |
  | The initial quote is already eaten.             |
  `------------------------------------------------*/


case 92:
YY_RULE_SETUP
#line 531 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_FINISH;
    BEGIN INITIAL;
    loc->start = token_start;
    complain (loc, Wyacc,
              _("POSIX Yacc does not support string literals"));
    RETURN_VALUE (STRING, last_string);
  }
	YY_BREAK
case YY_STATE_EOF(SC_ESCAPED_STRING):
#line 539 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "\"");
	YY_BREAK
case 93:
/* rule 93 can match eol */
YY_RULE_SETUP
#line 540 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_newline (token_start, "\"");
	YY_BREAK

/*----------------------------------------------------------.
  | Scanning a Bison character literal, decoding its escapes. |
  | The initial quote is already eaten.                       |
  `----------------------------------------------------------*/


case 94:
YY_RULE_SETUP
#line 550 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_FINISH;
    loc->start = token_start;
    val->CHAR = last_string[0];

    /* FIXME: Eventually, make these errors.  */
    if (last_string[0] == '\0')
    {
      complain (loc, Wother, _("empty character literal"));
      /* '\0' seems dangerous even if we are about to complain.  */
      val->CHAR = '\'';
    }
    else if (last_string[1] != '\0')
      complain (loc, Wother,
                _("extra characters in character literal"));
    STRING_FREE;
    BEGIN INITIAL;
    return CHAR;
  }
	YY_BREAK
case 95:
/* rule 95 can match eol */
YY_RULE_SETUP
#line 569 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_newline (token_start, "'");
	YY_BREAK
case YY_STATE_EOF(SC_ESCAPED_CHARACTER):
#line 570 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "'");
	YY_BREAK

/*--------------------------------------------------------------.
  | Scanning a tag.  The initial angle bracket is already eaten.  |
  `--------------------------------------------------------------*/


case 96:
YY_RULE_SETUP
#line 581 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    --nesting;
    if (nesting < 0)
      {
        STRING_FINISH;
        loc->start = token_start;
        val->TAG = uniqstr_new (last_string);
        STRING_FREE;
        BEGIN INITIAL;
        return TAG;
      }
    STRING_GROW;
  }
	YY_BREAK
case 97:
/* rule 97 can match eol */
YY_RULE_SETUP
#line 595 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW;
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 596 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW; nesting += yyleng;
	YY_BREAK
case YY_STATE_EOF(SC_TAG):
#line 598 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, ">");
	YY_BREAK

/*----------------------------.
  | Decode escaped characters.  |
  `----------------------------*/


case 99:
YY_RULE_SETUP
#line 607 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    verify (UCHAR_MAX < ULONG_MAX);
    long c = strtol (yytext + 1, NULL, 8);
    if (0 < c && c <= UCHAR_MAX)
      obstack_1grow (&obstack_for_string, c);
    else
      complain (loc, complaint, _("invalid number after \\-escape: %s"),
                yytext+1);
  }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 617 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    verify (UCHAR_MAX < ULONG_MAX);
    long c = strtol (yytext + 2, NULL, 16);
    if (0 < c && c <= UCHAR_MAX)
      obstack_1grow (&obstack_for_string, c);
    else
      complain (loc, complaint, _("invalid number after \\-escape: %s"),
                yytext+1);
  }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 627 "/Users/akim/src/gnu/bison/src/scan-gram.l"
obstack_1grow (&obstack_for_string, '\a');
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 628 "/Users/akim/src/gnu/bison/src/scan-gram.l"
obstack_1grow (&obstack_for_string, '\b');
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 629 "/Users/akim/src/gnu/bison/src/scan-gram.l"
obstack_1grow (&obstack_for_string, '\f');
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 630 "/Users/akim/src/gnu/bison/src/scan-gram.l"
obstack_1grow (&obstack_for_string, '\n');
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 631 "/Users/akim/src/gnu/bison/src/scan-gram.l"
obstack_1grow (&obstack_for_string, '\r');
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 632 "/Users/akim/src/gnu/bison/src/scan-gram.l"
obstack_1grow (&obstack_for_string, '\t');
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 633 "/Users/akim/src/gnu/bison/src/scan-gram.l"
obstack_1grow (&obstack_for_string, '\v');
	YY_BREAK
/* \\[\"\'?\\] would be shorter, but it confuses xgettext.  */
case 108:
YY_RULE_SETUP
#line 636 "/Users/akim/src/gnu/bison/src/scan-gram.l"
obstack_1grow (&obstack_for_string, yytext[1]);
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 638 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    int c = convert_ucn_to_byte (yytext);
    if (c <= 0)
      complain (loc, complaint, _("invalid number after \\-escape: %s"),
                yytext+1);
    else
      obstack_1grow (&obstack_for_string, c);
  }
	YY_BREAK
case 110:
/* rule 110 can match eol */
YY_RULE_SETUP
#line 646 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    char const *p = yytext + 1;
    /* Quote only if escaping won't make the character visible.  */
    if (c_isspace ((unsigned char) *p) && c_isprint ((unsigned char) *p))
      p = quote (p);
    else
      p = quotearg_style_mem (escape_quoting_style, p, 1);
    complain (loc, complaint, _("invalid character after \\-escape: %s"),
              p);
  }
	YY_BREAK

/*--------------------------------------------.
  | Scanning user-code characters and strings.  |
  `--------------------------------------------*/


case 111:
/* rule 111 can match eol */
YY_RULE_SETUP
#line 664 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW;
	YY_BREAK



case 112:
YY_RULE_SETUP
#line 669 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW; BEGIN context_state;
	YY_BREAK
case 113:
/* rule 113 can match eol */
YY_RULE_SETUP
#line 670 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_newline (token_start, "'");
	YY_BREAK
case YY_STATE_EOF(SC_CHARACTER):
#line 671 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "'");
	YY_BREAK



case 114:
YY_RULE_SETUP
#line 676 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW; BEGIN context_state;
	YY_BREAK
case 115:
/* rule 115 can match eol */
YY_RULE_SETUP
#line 677 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_newline (token_start, "\"");
	YY_BREAK
case YY_STATE_EOF(SC_STRING):
#line 678 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "\"");
	YY_BREAK

/*---------------------------------------------------.
  | Strings, comments etc. can be found in user code.  |
  `---------------------------------------------------*/


case 116:
YY_RULE_SETUP
#line 688 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW;
    context_state = YY_START;
    token_start = loc->start;
    BEGIN SC_CHARACTER;
  }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 694 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW;
    context_state = YY_START;
    token_start = loc->start;
    BEGIN SC_STRING;
  }
	YY_BREAK
case 118:
/* rule 118 can match eol */
YY_RULE_SETUP
#line 700 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW;
    context_state = YY_START;
    token_start = loc->start;
    BEGIN SC_COMMENT;
  }
	YY_BREAK
case 119:
/* rule 119 can match eol */
YY_RULE_SETUP
#line 706 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW;
    context_state = YY_START;
    BEGIN SC_LINE_COMMENT;
  }
	YY_BREAK

/*-----------------------------------------------------------.
  | Scanning some code in braces (actions, predicates). The    |
  | initial "{" is already eaten.                              |
  `-----------------------------------------------------------*/


case 120:
/* rule 120 can match eol */
YY_RULE_SETUP
#line 722 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW; nesting++;
	YY_BREAK
case 121:
/* rule 121 can match eol */
YY_RULE_SETUP
#line 723 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW; nesting--;
	YY_BREAK
/* Tokenize '<<%' correctly (as '<<' '%') rather than incorrectly
     (as '<' '<%').  */
case 122:
/* rule 122 can match eol */
YY_RULE_SETUP
#line 727 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW;
	YY_BREAK
case YY_STATE_EOF(SC_BRACED_CODE):
case YY_STATE_EOF(SC_PREDICATE):
#line 729 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (code_start, "}");
	YY_BREAK



case 123:
YY_RULE_SETUP
#line 734 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    obstack_1grow (&obstack_for_string, '}');

    --nesting;
    if (nesting < 0)
      {
        STRING_FINISH;
        loc->start = code_start;
        BEGIN INITIAL;
        RETURN_VALUE (BRACED_CODE, last_string);
      }
  }
	YY_BREAK



case 124:
YY_RULE_SETUP
#line 750 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    --nesting;
    if (nesting < 0)
      {
        STRING_FINISH;
        loc->start = code_start;
        BEGIN INITIAL;
        RETURN_VALUE (BRACED_PREDICATE, last_string);
      }
    else
      obstack_1grow (&obstack_for_string, '}');
  }
	YY_BREAK

/*--------------------------------------------------------------.
  | Scanning some prologue: from "%{" (already scanned) to "%}".  |
  `--------------------------------------------------------------*/


case 125:
YY_RULE_SETUP
#line 770 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_FINISH;
    loc->start = code_start;
    BEGIN INITIAL;
    RETURN_VALUE (PROLOGUE, last_string);
  }
	YY_BREAK
case YY_STATE_EOF(SC_PROLOGUE):
#line 777 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (code_start, "%}");
	YY_BREAK

/*---------------------------------------------------------------.
  | Scanning the epilogue (everything after the second "%%", which |
  | has already been eaten).                                       |
  `---------------------------------------------------------------*/


case YY_STATE_EOF(SC_EPILOGUE):
#line 788 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_FINISH;
    loc->start = code_start;
    BEGIN INITIAL;
    RETURN_VALUE (EPILOGUE, last_string);
  }
	YY_BREAK

/*-----------------------------------------------------.
  | By default, grow the string obstack with the input.  |
  `-----------------------------------------------------*/


/* Accept multibyte characters in one block instead of byte after
     byte, so that add_column_width and mbsnwidth can compute correct
     screen width.

     Add a fallthrough "|." so that non UTF-8 input is still accepted
     and does not jam the scanner.  */
case 126:
/* rule 126 can match eol */
YY_RULE_SETUP
#line 809 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW;
	YY_BREAK

case 127:
YY_RULE_SETUP
#line 812 "/Users/akim/src/gnu/bison/src/scan-gram.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 2968 "src/scan-gram.c"
case YY_STATE_EOF(SC_RETURN_BRACKETED_ID):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
/* %if-c-only */
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
/* %endif */
/* %if-c++-only */
/* %endif */
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
/* %% [14.0] code to do back-up for compressed tables and set up yy_cp goes here */
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */
/* %ok-for-header */

/* %if-c++-only */
/* %not-for-header */
/* %ok-for-header */

/* %endif */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
/* %if-c-only */
static int yy_get_next_buffer (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

/* %if-c-only */
/* %not-for-header */
    static yy_state_type yy_get_previous_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
/* %% [15.0] code to get the start state into yy_current_state goes here */
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
/* %% [16.0] code to find the next state goes here */
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 72);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 600 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
/* %if-c-only */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	int yy_is_jam;
    /* %% [17.0] code to find the next state, and perhaps do backing up, goes here */
	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 72;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 600 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 599);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT
/* %if-c-only */

    static void yyunput (int c, char * yy_bp )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

/* %% [18.0] update yylineno here */

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}
/* %if-c-only */

/* %endif */
#endif

/* %if-c-only */
#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

/* %endif */
/* %if-c++-only */
/* %endif */
{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

/* %% [19.0] update BOL and yylineno */
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
/* %if-c-only */
#endif	/* ifndef YY_NO_INPUT */
/* %endif */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
/* %if-c-only */
    void yyrestart  (FILE * input_file )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/* %if-c++-only */
/* %endif */

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
/* %if-c-only */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

/* %if-c-only */
static void yy_load_buffer_state  (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
/* %if-c-only */
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
/* %endif */
/* %if-c++-only */
/* %endif */
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
/* %if-c-only */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/* %if-c++-only */
/* %endif */

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
/* %if-c-only */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
/* %if-c-only */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )
/* %endif */
/* %if-c++-only */
/* %endif */

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

/* %if-c-only */
	b->yy_input_file = file;
/* %endif */
/* %if-c++-only */
/* %endif */
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

/* %if-c-only */

        b->yy_is_interactive = 0;
    
/* %endif */
/* %if-c++-only */
/* %endif */
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
/* %if-c-only */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/* %if-c-or-c++ */
/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
/* %if-c-only */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}
/* %endif */

/* %if-c-or-c++ */
/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
/* %if-c-only */
void yypop_buffer_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}
/* %endif */

/* %if-c-or-c++ */
/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
/* %if-c-only */
static void yyensure_buffer_stack (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}
/* %endif */

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

/* %if-c-only */
static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}
/* %endif */
/* %if-c++-only */
/* %endif */

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/* %if-c-only */
/* %if-reentrant */
/* %endif */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/* %if-reentrant */
/* %endif */

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

/* %endif */

/* %if-reentrant */
/* %if-bison-bridge */
/* %endif */
/* %endif if-c-only */

/* %if-c-only */
static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}
/* %endif */

/* %if-c-only SNIP! this currently causes conflicts with the c++ scanner */
/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

/* %if-reentrant */
/* %endif */
    return 0;
}
/* %endif */

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

/* %if-tables-serialization definitions */
/* %define-yytables   The name for this specific scanner's tables. */
#define YYTABLES_NAME "yytables"
/* %endif */

/* %ok-for-header */

#line 812 "/Users/akim/src/gnu/bison/src/scan-gram.l"



/*------------------------------------------------------.
| Scan NUMBER for a base-BASE integer at location LOC.  |
`------------------------------------------------------*/

static int
scan_integer (char const *number, int base, location loc)
{
  verify (INT_MAX < ULONG_MAX);
  if (base == 16)
    complain (&loc, Wyacc,
              _("POSIX Yacc does not support hexadecimal literals"));

  errno = 0;
  long num = strtol (number, NULL, base);

  if (! (0 <= num && num <= INT_MAX && errno == 0))
    {
      complain (&loc, complaint, _("integer out of range: %s"),
                quote (number));
      num = INT_MAX;
    }

  return num;
}


/*------------------------------------------------------------------.
| Convert universal character name UCN to a single-byte character,  |
| and return that character.  Return -1 if UCN does not correspond  |
| to a single-byte character.                                       |
`------------------------------------------------------------------*/

static int
convert_ucn_to_byte (char const *ucn)
{
  verify (UCHAR_MAX <= INT_MAX);
  long code = strtol (ucn + 2, NULL, 16);

  /* FIXME: Currently we assume Unicode-compatible unibyte characters
     on ASCII hosts (i.e., Latin-1 on hosts with 8-bit bytes).  On
     non-ASCII hosts we support only the portable C character set.
     These limitations should be removed once we add support for
     multibyte characters.  */

  if (! (0 <= code && code <= UCHAR_MAX))
    return -1;

#if ! ('$' == 0x24 && '@' == 0x40 && '`' == 0x60 && '~' == 0x7e)
  {
    /* A non-ASCII host.  Use CODE to index into a table of the C
       basic execution character set, which is guaranteed to exist on
       all Standard C platforms.  This table also includes '$', '@',
       and '`', which are not in the basic execution character set but
       which are unibyte characters on all the platforms that we know
       about.  */
    static signed char const table[] =
      {
        '\0',   -1,   -1,   -1,   -1,   -1,   -1, '\a',
        '\b', '\t', '\n', '\v', '\f', '\r',   -1,   -1,
          -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
          -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
         ' ',  '!',  '"',  '#',  '$',  '%',  '&', '\'',
         '(',  ')',  '*',  '+',  ',',  '-',  '.',  '/',
         '0',  '1',  '2',  '3',  '4',  '5',  '6',  '7',
         '8',  '9',  ':',  ';',  '<',  '=',  '>',  '?',
         '@',  'A',  'B',  'C',  'D',  'E',  'F',  'G',
         'H',  'I',  'J',  'K',  'L',  'M',  'N',  'O',
         'P',  'Q',  'R',  'S',  'T',  'U',  'V',  'W',
         'X',  'Y',  'Z',  '[', '\\',  ']',  '^',  '_',
         '`',  'a',  'b',  'c',  'd',  'e',  'f',  'g',
         'h',  'i',  'j',  'k',  'l',  'm',  'n',  'o',
         'p',  'q',  'r',  's',  't',  'u',  'v',  'w',
         'x',  'y',  'z',  '{',  '|',  '}',  '~'
      };

    code = code < sizeof table ? table[code] : -1;
  }
#endif

  return code;
}


/*---------------------------------------------------------------------.
| Handle '#line INT( "FILE")?\n'.  ARGS has already skipped '#line '.  |
`---------------------------------------------------------------------*/

static void
handle_syncline (char *args, location loc)
{
  char *file;
  errno = 0;
  long lineno = strtol (args, &file, 10);
  if (! (0 <= lineno && lineno <= INT_MAX && errno == 0))
    {
      complain (&loc, Wother, _("line number overflow"));
      lineno = INT_MAX;
    }

  file = strchr (file, '"');
  if (file)
    {
      *strchr (file + 1, '"') = '\0';
      current_file = uniqstr_new (file + 1);
    }
  boundary_set (&scanner_cursor, current_file, lineno, 1, 1);
}


/*----------------------------------------------------------------.
| For a token or comment starting at START, report message MSGID, |
| which should say that an end marker was found before the        |
| expected TOKEN_END. Then, pretend that TOKEN_END was found.     |
`----------------------------------------------------------------*/

static void
unexpected_end (boundary start, char const *msgid, char const *token_end)
{
  location loc;
  loc.start = start;
  loc.end = scanner_cursor;
  size_t i = strlen (token_end);

  /* Adjust scanner cursor so that any later message does not count
     the characters about to be inserted.  */
  scanner_cursor.column -= i;
  scanner_cursor.byte -= i;

  while (i != 0)
    unput (token_end[--i]);

  token_end = quote (token_end);
  /* Instead of '\'', display "'".  */
  if (STREQ (token_end, "'\\''"))
    token_end = "\"'\"";
  complain (&loc, complaint, msgid, token_end);
}


/*------------------------------------------------------------------------.
| Report an unexpected EOF in a token or comment starting at START.       |
| An end of file was encountered and the expected TOKEN_END was missing.  |
| After reporting the problem, pretend that TOKEN_END was found.          |
`------------------------------------------------------------------------*/

static void
unexpected_eof (boundary start, char const *token_end)
{
  unexpected_end (start, _("missing %s at end of file"), token_end);
}


/*----------------------------------------.
| Likewise, but for unexpected newlines.  |
`----------------------------------------*/

static void
unexpected_newline (boundary start, char const *token_end)
{
  unexpected_end (start, _("missing %s at end of line"), token_end);
}


void
gram_scanner_open (const char *gram)
{
  gram__flex_debug = trace_flag & trace_scan;
  gram_debug = trace_flag & trace_parse;
  obstack_init (&obstack_for_string);
  current_file = gram;
  gram_in = xfopen (gram, "r");
}


void
gram_scanner_close ()
{
  xfclose (gram_in);
  /* Reclaim Flex's buffers.  */
  yylex_destroy ();
}



void
gram_scanner_free (void)
{
  obstack_free (&obstack_for_string, 0);
}

